@@ -1,4 +1,4 @@
-use 5.10.0;
+use 5.14.0;
 use strict;
 use warnings;
 
@@ -6,7 +6,7 @@ package Dist::Iller::DocType::Dist;
 
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
 # ABSTRACT: Turn the Dist::Iller config into a dist.ini file
-our $VERSION = '0.1409';
+our $VERSION = '0.1410';
 
 use Dist::Iller::Elk;
 with qw/
@@ -18,7 +18,7 @@ with qw/
 use Types::Standard qw/HashRef ArrayRef Str Int Bool/;
 use PerlX::Maybe qw/maybe provided/;
 use List::Util qw/any/;
-
+use DateTime;
 
 has name => (
     is => 'rw',
@@ -58,6 +58,7 @@ has copyright_year => (
     isa => Int,
     predicate => 1,
     init_arg => undef,
+    default => sub { DateTime->now->year }
 );
 has add_prereqs_as_authordeps => (
     is => 'rw',
@@ -299,7 +300,7 @@ Dist::Iller::DocType::Dist - Turn the Dist::Iller config into a dist.ini file
 
 =head1 VERSION
 
-Version 0.1409, released 2020-12-27.
+Version 0.1410, released 2020-12-31.
 
 =head1 SOURCE
 
@@ -315,7 +316,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Erik Carlsson.
+This software is copyright (c) 2020 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
